# Configuration

This folder stores configuration information for all services.

Store non-sensitive configuration in `dev.env`.



If necessary, you can store other sensitive information in `secret.env`.
